=============================
django-dedal
=============================

.. image:: https://badge.fury.io/py/django-dedal.png
    :target: https://badge.fury.io/py/django-dedal

.. image:: https://travis-ci.org/ar4s/django-dedal.png?branch=master
    :target: https://travis-ci.org/ar4s/django-dedal

.. image:: https://coveralls.io/repos/ar4s/django-dedal/badge.png?branch=master
    :target: https://coveralls.io/r/ar4s/django-dedal?branch=master

Fast CRUD builder.

Documentation
-------------

The full documentation is at https://django-dedal.readthedocs.org.

Quickstart
----------

Install django-dedal::

    pip install django-dedal

Then use it in a project::

    import django-dedal

Features
--------

* TODO
